# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class ArchiveModule(Module):
    name = "Archive"
    module_id = "archive"

    def get_url(self, project):
        return reverse("archive:list", kwargs={"project": project.pk})

    def is_configured(self, project):
        from .models import Archive

        return Archive.objects.filter(projects=project)


def get_search_url():
    return reverse("archive:search")


def get_api_root():
    return reverse("archive:api_root")


def serialize_project(project):
    from .models import Archive

    query = Archive.objects.filter(projects=project)
    result = {}
    if query:
        result["heliport:has_Archive"] = [
            {
                "heliport:archive_id": a.archive_id,
                "datacite:hasDescription": a.description,
            }
            for a in query
        ]

    return result
