# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from rdflib import Namespace
from rest_framework import serializers

from heliport.core.attribute_description import TypeAttribute
from heliport.core.serializers import (
    DigitalObjectDATACITESerializer,
    datacite_serializers,
    register_digital_object_attributes,
)
from heliport.core.vocabulary import FABIO

from .models import Archive

hzdr_namespace = Namespace("https://hdl.handle.net/20.500.12865/hzdr_vocab.v1#")


class ArchiveSerializer(serializers.ModelSerializer):
    archive_number = serializers.CharField()
    url = serializers.CharField(source="link")

    def create(self, validated_data):
        link = validated_data.pop("link")
        n = validated_data.pop("archive_number")
        instance = super().create(validated_data)
        instance.link = link
        instance.archive_number = n
        return instance

    class Meta:
        model = Archive
        fields = [
            "archive_id",
            "label",
            "description",
            "persistent_id",
            "archive_number",
            "url",
        ]


@datacite_serializers.register(Archive)
class ArchiveDATACITESerializer(DigitalObjectDATACITESerializer):
    def resource_type(self, archive):
        return "archive", "Dataset"


@register_digital_object_attributes(Archive)
def archive_attributes():
    return [
        TypeAttribute(FABIO.ArchivalDocument),
    ]
