# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.apps import AppConfig
from django.db.models.signals import post_migrate

from .vocabulary_core import insert_core_vocabulary


def post_migrate_handler(**kwargs):
    insert_core_vocabulary()


class HeliportConfig(AppConfig):
    """
    App configuration for the main HELIPORT app. This is part of Django's plugin system
    """

    name = "heliport.core"

    def ready(self):
        """register hooks and import settings"""
        from .conf import HeliportAppConf, HeliportHandlesAppConf

        assert HeliportAppConf
        assert HeliportHandlesAppConf
        post_migrate.connect(post_migrate_handler, sender=self)
