# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 3.1.14 on 2022-02-17 13:23

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models

import heliport.core.utils.IDs


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="DigitalObject",
            fields=[
                (
                    "digital_object_id",
                    models.AutoField(primary_key=True, serialize=False),
                ),
                ("handle", models.CharField(blank=True, max_length=500, null=True)),
                (
                    "generated_handle",
                    models.CharField(blank=True, max_length=500, null=True),
                ),
                ("category", models.TextField()),
                ("label", models.TextField()),
                ("description", models.TextField(blank=True, default="")),
                (
                    "created",
                    models.DateTimeField(
                        auto_now_add=True, verbose_name="date created"
                    ),
                ),
                (
                    "deleted",
                    models.DateTimeField(
                        blank=True, null=True, verbose_name="date deleted"
                    ),
                ),
                (
                    "permission",
                    models.IntegerField(
                        choices=[(1, "Public"), (2, "Project"), (3, "Private")],
                        default=2,
                    ),
                ),
                (
                    "special_heliport_role",
                    models.CharField(blank=True, max_length=30, null=True),
                ),
            ],
        ),
        migrations.CreateModel(
            name="Group",
            fields=[
                (
                    "group_id",
                    models.CharField(max_length=100, primary_key=True, serialize=False),
                ),
            ],
        ),
        migrations.CreateModel(
            name="HeliportGroup",
            fields=[
                ("group_id", models.AutoField(primary_key=True, serialize=False)),
                ("group_name", models.TextField(default="UnnamedGroup")),
            ],
        ),
        migrations.CreateModel(
            name="HeliportUser",
            fields=[
                ("user_id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "authentication_backend_id",
                    models.CharField(max_length=100, null=True),
                ),
                ("display_name", models.CharField(default="<User>", max_length=100)),
                ("orcid", models.CharField(blank=True, max_length=100, null=True)),
                (
                    "auth_user",
                    models.OneToOneField(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="LoginInfo",
            fields=[
                ("login_info_id", models.AutoField(primary_key=True, serialize=False)),
                ("username", models.CharField(blank=True, max_length=100)),
                ("password", models.CharField(blank=True, max_length=100)),
                ("key", models.TextField(blank=True)),
                ("machine", models.CharField(blank=True, max_length=100)),
                ("name", models.CharField(max_length=100)),
                (
                    "type",
                    models.CharField(
                        choices=[
                            ("ssh connection", "Ssh"),
                            ("username and password", "User Password"),
                            ("authentication token", "Token"),
                        ],
                        max_length=50,
                    ),
                ),
                ("data", models.TextField(blank=True)),
                ("slurm", models.BooleanField(default=False)),
                (
                    "user",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="core.heliportuser",
                    ),
                ),
                (
                    "via",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="core.logininfo",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="DigitalObjectRelation",
            fields=[
                (
                    "digital_object_relation_id",
                    models.AutoField(primary_key=True, serialize=False),
                ),
                (
                    "object",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="reverse_relations",
                        to="core.digitalobject",
                    ),
                ),
                (
                    "predicate",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="predicate_relations",
                        to="core.digitalobject",
                    ),
                ),
                (
                    "subject",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="relations",
                        to="core.digitalobject",
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name="digitalobject",
            name="co_owners",
            field=models.ManyToManyField(
                blank=True,
                related_name="co_owned_digital_objects",
                to="core.HeliportUser",
            ),
        ),
        migrations.AddField(
            model_name="digitalobject",
            name="heliport_groups",
            field=models.ManyToManyField(blank=True, to="core.HeliportGroup"),
        ),
        migrations.AddField(
            model_name="digitalobject",
            name="owner",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="core.heliportuser",
            ),
        ),
        migrations.CreateModel(
            name="Project",
            fields=[
                (
                    "digitalobject_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        to="core.digitalobject",
                    ),
                ),
                ("project_id", models.AutoField(primary_key=True, serialize=False)),
                ("hzdr_id", models.CharField(max_length=100)),
                (
                    "uuid",
                    models.UUIDField(
                        default=heliport.core.utils.IDs.generate_object_id,
                        editable=False,
                    ),
                ),
                (
                    "original_id",
                    models.CharField(blank=True, max_length=100, null=True),
                ),
                (
                    "group",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="core.group",
                    ),
                ),
            ],
            bases=("core.digitalobject",),
        ),
        migrations.AddField(
            model_name="digitalobject",
            name="projects",
            field=models.ManyToManyField(blank=True, to="core.Project"),
        ),
    ]
