# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 4.0.5 on 2022-07-04 09:49

from django.db import migrations
from rdflib import DCTERMS, FOAF, RDF, RDFS, URIRef
from rdflib.namespace import DCAM, Namespace

HELIPORT_NS = Namespace("https://hdl.handle.net/20.500.12865/heliport_vocab.v1#")


def build_set_attributes_for_role(model):
    def set_attribs(role_name_in_db, label, persistent_id=None):
        obj, is_new = model.objects.get_or_create(special_heliport_role=role_name_in_db)
        obj.label = label
        if persistent_id is not None:
            obj.persistent_id = persistent_id
        obj.save()
        return obj

    return set_attribs


def build_set_type(relation_model, type_obj, the_type):
    def set_property(obj):
        relation_model.objects.get_or_create(
            subject=obj, predicate=type_obj, object=the_type
        )

    return set_property


def insert_core_vocabulary(apps, schema_editor):
    set_attribs = build_set_attributes_for_role(apps.get_model("core", "DigitalObject"))
    class_list = []
    property_list = []
    property_obj = set_attribs(
        role_name_in_db="Property",
        label="Property",
        persistent_id=RDF.Property,
    )
    class_list.append(property_obj)
    class_obj = set_attribs(
        role_name_in_db="Class",
        label="Class",
        persistent_id=RDFS.Class,
    )
    class_list.append(class_obj)
    class_list.append(
        set_attribs(
            role_name_in_db="Namespace",
            label="Namespace",
            persistent_id=DCAM.VocabularyEncodingScheme,
        )
    )
    class_list.append(
        set_attribs(
            role_name_in_db="HELIPORT",
            persistent_id="https://hdl.handle.net/20.500.12865/HELIPORT",
            label="HELIPORT",
        )
    )
    class_list.append(
        set_attribs(
            role_name_in_db="Project",
            label="Project",
            persistent_id=FOAF.Project,
        )
    )

    type_obj = set_attribs(
        role_name_in_db="type",
        label="type",
        persistent_id=RDF.type,
    )
    property_list.append(type_obj)
    property_list.append(
        set_attribs(
            role_name_in_db="suggested_property",
            label="suggested property",
            persistent_id=DCAM.domainIncludes,
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="subnamespace_of",
            label="subnamespace of",
            persistent_id=HELIPORT_NS.subNamespaceOf,
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="subclass_of",
            label="subclass of",
            persistent_id=RDFS.subClassOf,
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="label",
            label="label",
            persistent_id=RDFS.label,
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="description",
            label="description",
            persistent_id=DCTERMS.description,
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="sub_property_of",
            label="subPropertyOf",
            persistent_id=RDFS.subPropertyOf,
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="has_tag",
            label="has Tag",
            persistent_id=URIRef("http://rdfs.org/scot/ns#has_tag"),
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="has_part",
            label="has Part",
            persistent_id=DCTERMS.hasPart,
        )
    )
    # something is used in a job
    # A is input_of JOB if JOB is described_by_process TOOL which has_input I and A is described_by_parameter I
    property_list.append(set_attribs(role_name_in_db="input_of", label="input of"))
    # input parameter in a workflow description
    property_list.append(
        set_attribs(
            role_name_in_db="has_input",
            label="hasInput",
            persistent_id=URIRef("http://purl.org/wf4ever/wfdesc#hasInput"),
        )
    )
    # something is used as the input parameter defined by has_input
    property_list.append(
        set_attribs(
            role_name_in_db="described_by_parameter",
            label="describedByParameter",
            persistent_id=URIRef("http://purl.org/wf4ever/wfprov#describedByParameter"),
        )
    )
    # a job is described by some workflow/tool
    property_list.append(
        set_attribs(
            role_name_in_db="described_by_process",
            label="describedByProcess",
            persistent_id=URIRef("http://purl.org/wf4ever/wfprov#describedByProcess"),
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="primary_topic",
            label="primaryTopic",
            persistent_id=FOAF.primaryTopic,
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="status",
            label="status",
            persistent_id=URIRef("http://purl.org/ontology/bibo/status"),
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="has_identifier",
            label="has Identifier",
            persistent_id=URIRef("http://purl.org/spar/datacite/hasIdentifier"),
        )
    )
    property_list.append(
        set_attribs(
            role_name_in_db="filename",
            label="filename",
            persistent_id=URIRef(
                "https://www.semanticdesktop.org/ontologies/2007/03/22/nfo/#fileName"
            ),
        )
    )

    set_is_property = build_set_type(
        apps.get_model("core", "DigitalObjectRelation"), type_obj, property_obj
    )
    set_is_class = build_set_type(
        apps.get_model("core", "DigitalObjectRelation"), type_obj, class_obj
    )
    for p in property_list:
        set_is_property(p)
    for c in class_list:
        set_is_class(c)


class Migration(migrations.Migration):
    dependencies = [
        ("core", "0015_digitalobject_last_modified"),
    ]

    operations = [
        migrations.RunPython(insert_core_vocabulary, lambda *args: None),
    ]
