# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

import abc

from django.contrib.auth import login

from heliport.core.models import HeliportUser


class UserInformationManager:
    @abc.abstractmethod
    def update(self, user):
        pass

    @abc.abstractmethod
    def get_display_name(self, user):
        pass

    @abc.abstractmethod
    def get_group(self, user):
        pass

    @abc.abstractmethod
    def get_authentication_backend_id(self, user):
        pass

    @abc.abstractmethod
    def login(self, user, request):
        pass

    @abc.abstractmethod
    def import_groups(self):
        pass

    @abc.abstractmethod
    def import_users_and_groups(self):
        pass

    @abc.abstractmethod
    def get_users_by_group(self, group):
        pass

    def fetch_user(self, user):
        self.update(user)
        display_name = self.get_display_name(user)
        authentication_backend_id = self.get_authentication_backend_id(user)

        hp_user = HeliportUser.objects.filter(auth_user=user).first()
        if hp_user is None:
            hp_user = HeliportUser.objects.filter(
                authentication_backend_id=authentication_backend_id
            ).first()
        if hp_user is None:
            hp_user, user_is_new = HeliportUser.objects.get_or_create(auth_user=user)

        if (
            hp_user.display_name != display_name
            or hp_user.authentication_backend_id != authentication_backend_id
            or hp_user.auth_user != user
        ):
            hp_user.display_name = display_name
            hp_user.authentication_backend_id = authentication_backend_id
            hp_user.auth_user = user
            hp_user.save()


class BasicUserInformationManager(UserInformationManager):
    def get_display_name(self, user):
        if hasattr(user, "heliportuser"):
            result = user.heliportuser.display_name
        else:
            result = f"{user.first_name} {user.last_name}"
        if not result:
            result = user.username
        return result.strip()

    def get_group(self, user):
        return None

    def get_authentication_backend_id(self, user):
        return f"BASIC{user.pk}"

    def login(self, user, request):
        login(request, user)

    def import_groups(self):
        pass

    def import_users_and_groups(self):
        pass

    def get_users_by_group(self, group):
        return []

    def update(self, user):
        pass
