# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 3.1.14 on 2022-02-17 13:23

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("core", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Executable",
            fields=[
                (
                    "digitalobject_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        to="core.digitalobject",
                    ),
                ),
                ("executable_id", models.AutoField(primary_key=True, serialize=False)),
                ("cwl_json", models.TextField(blank=True, default="")),
                (
                    "cwl_type",
                    models.IntegerField(choices=[(2, "Yaml"), (1, "Json")], default=1),
                ),
                (
                    "type",
                    models.IntegerField(
                        choices=[(1, "Tool"), (2, "Workflow"), (3, "Arbitrary Cwl")]
                    ),
                ),
                (
                    "original_id",
                    models.CharField(blank=True, max_length=100, null=True),
                ),
            ],
            bases=("core.digitalobject",),
        ),
        migrations.CreateModel(
            name="Job",
            fields=[
                (
                    "digitalobject_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        to="core.digitalobject",
                    ),
                ),
                ("job_id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("Running", "Running"),
                            ("Paused", "Paused"),
                            ("Stopped", "Stopped"),
                        ],
                        default="Stopped",
                        max_length=80,
                    ),
                ),
                ("output_text", models.TextField()),
                (
                    "output_code",
                    models.IntegerField(
                        choices=[
                            (-1, "Undefined"),
                            (0, "Message"),
                            (1, "Warning"),
                            (2, "Error"),
                        ],
                        default=-1,
                    ),
                ),
                ("cwl_json", models.TextField(blank=True, default="")),
                ("repeat", models.BooleanField(default=False)),
                ("interval", models.IntegerField(default=0)),
                ("setup_command", models.TextField(blank=True)),
                ("cmd_options", models.TextField(blank=True, default="--time=10")),
                (
                    "original_id",
                    models.CharField(blank=True, max_length=100, null=True),
                ),
                (
                    "base_executable",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="cwl_execution.executable",
                    ),
                ),
            ],
            bases=("core.digitalobject",),
        ),
        migrations.CreateModel(
            name="UserJobConfig",
            fields=[
                (
                    "user_job_config_id",
                    models.AutoField(primary_key=True, serialize=False),
                ),
                ("directory", models.TextField()),
                (
                    "original_id",
                    models.CharField(blank=True, max_length=100, null=True),
                ),
                (
                    "job",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="cwl_execution.job",
                    ),
                ),
                (
                    "ssh_login",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="core.logininfo",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="ExecutionLog",
            fields=[
                (
                    "execution_log_id",
                    models.AutoField(primary_key=True, serialize=False),
                ),
                ("start_time", models.DateTimeField()),
                ("end_time", models.DateTimeField(blank=True, null=True)),
                ("memory_usage", models.TextField(default="")),
                ("execution_id", models.TextField(blank=True, null=True)),
                ("aborted", models.BooleanField(default=False)),
                ("step_times", models.TextField(blank=True, null=True)),
                (
                    "original_id",
                    models.CharField(blank=True, max_length=100, null=True),
                ),
                (
                    "config",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="cwl_execution.userjobconfig",
                    ),
                ),
            ],
        ),
    ]
