# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class DataManagementPlanModule(Module):
    name = "Data Management Plan"
    module_id = "data_management_plan"

    def get_url(self, project):
        return reverse("data_management_plan:list", kwargs={"project": project.pk})

    def is_configured(self, project):
        from .models import DataManagementPlan

        return DataManagementPlan.objects.filter(projects=project)


def get_api_root():
    return reverse("data_management_plan:api_root")


def get_search_url():
    return reverse("data_management_plan:search")


def serialize_project(project):
    from .models import DataManagementPlan

    query = DataManagementPlan.objects.filter(projects=project)
    result = {}
    if query:
        result["heliport:has_DataManagementPlan"] = [
            {
                "heliport:data_management_plan_id": dmp.data_management_plan_id,
                "datacite:uri": dmp.link,
                "datacite:hasDescription": dmp.description,
            }
            for dmp in query
        ]

    return result
