# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from rest_framework import serializers

from heliport.core.attribute_description import TypeAttribute
from heliport.core.serializers import (
    DigitalObjectDATACITESerializer,
    datacite_serializers,
    register_digital_object_attributes,
)
from heliport.core.vocabulary import FABIO

from .models import DataManagementPlan


class DataManagementPlanSerializer(serializers.ModelSerializer):
    link = serializers.CharField()

    def create(self, validated_data):
        link = validated_data.pop("link")
        instance = super().create(validated_data)
        instance.link = link
        return instance

    class Meta:
        model = DataManagementPlan
        fields = ["data_management_plan_id", "description", "link", "projects"]


@datacite_serializers.register(DataManagementPlan)
class DmpDATACITESerializer(DigitalObjectDATACITESerializer):
    def resource_type(self, dmp):
        return "DataManagementPlan", "Text"


@register_digital_object_attributes(DataManagementPlan)
def dmp_attributes():
    return [
        TypeAttribute(FABIO.DataMangementPlan),
    ]
