# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import include, path
from rest_framework import routers

from .views import (
    DataManagementPlanUpdateView,
    DataManagementPlanView,
    DataManagementPlanViewSet,
    SearchView,
)

app_name = "data_management_plan"
urlpatterns = [
    path("project/<int:project>/list/", DataManagementPlanView.as_view(), name="list"),
    path(
        "project/<int:project>/update/<int:pk>/",
        DataManagementPlanUpdateView.as_view(),
        name="update",
    ),
    path("search/", SearchView.as_view(), name="search"),
]

# for REST API:
router = routers.DefaultRouter()
router.register(
    r"data_management_plan", DataManagementPlanViewSet, basename="data_management_plan"
)

urlpatterns += [
    path("api-root/", router.get_api_root_view(), name="api_root"),
    path("api/", include(router.urls)),
]
