# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class DataSourceModule(Module):
    name = "Data Source"
    module_id = "data_source"

    def get_url(self, project):
        return reverse("data_source:list", kwargs={"project": project.pk})

    def is_configured(self, project):
        from .models import DataSource

        return DataSource.objects.filter(projects=project)


def get_api_root():
    return reverse("data_source:api_root")


def get_search_url():
    return reverse("data_source:search")


def serialize_project(project):
    from .models import DataSource

    query = DataSource.objects.filter(projects=project)
    result = {}
    if query:
        result["heliport:has_DataSource"] = [
            {
                "heliport:data_source_id": ds.data_source_id,
                "datacite:uri": ds.uri,
                "heliport:use_computer": ds.login.machine if ds.login else None,
                "rdfs:label": ds.label,
                "datacite:hasDescription": ds.description,
            }
            for ds in query
        ]

    return result
