# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import include, path
from rest_framework import routers

from .views import (
    DataSourceUpdateView,
    DataSourceView,
    DataSourceViewSet,
    GeneralDataSourceOpenView,
    SearchView,
    SSHDataSourceOpenView,
    SubDataSourceCreateView,
)

app_name = "data_source"
urlpatterns = [
    path("project/<int:project>/list/", DataSourceView.as_view(), name="list"),
    path(
        "project/<int:project>/update/<int:pk>/",
        DataSourceUpdateView.as_view(),
        name="update",
    ),
    path(
        "project/<int:project>/download/<int:pk>/",
        SSHDataSourceOpenView.as_view(),
        name="download",
    ),
    path(
        "project/<int:project>/open/",
        GeneralDataSourceOpenView.as_view(),
        name="open",
    ),
    path(
        "project/<int:project>/<int:pk>/sub_data_source/",
        SubDataSourceCreateView.as_view(),
        name="sub_data_source",
    ),
    path("search/", SearchView.as_view(), name="search"),
]

# for REST API:
router = routers.DefaultRouter()
router.register(r"data_source", DataSourceViewSet, basename="data_source")

urlpatterns += [
    path("api-root/", router.get_api_root_view(), name="api_root"),
    path("api/", include(router.urls)),
]
