# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class DigitalObjectsModule(Module):
    name = "Digital Objects"
    module_id = "digital_objects"

    def get_url(self, project):
        return reverse("digital_objects:list", kwargs={"project": project.pk})

    def is_configured(self, project):
        from heliport.core.models import DigitalObject

        return bool(
            project.relations.all()
            or project.parts.filter(**DigitalObject.not_subclass_query())
        )


class ObjectGraphModule(Module):
    name = "Object Graph"
    module_id = "object_graph"
    icon = "fa-solid fa-diagram-project"

    def get_url(self, project):
        return reverse(
            "digital_objects:object_graph_list", kwargs={"project": project.pk}
        )

    def is_configured(self, project):
        from .models import ObjectGraph

        return ObjectGraph.objects.filter(projects=project)


def get_api_root():
    return reverse("digital_objects:api_root")


def get_search_url():
    return reverse("digital_objects:search")


def serialize_project(project):
    from heliport.core.models import DigitalObject

    query = project.parts.filter(**DigitalObject.not_subclass_query())
    result = {}
    if query:
        result["heliport:has_DigitalObject"] = [
            {
                "heliport:digital_object_id": do.digital_object_id,
                f"datacite:{do.identifier_scheme.datacite_id}": do.identifier_link,
                "rdfs:type": do.category_str,
                "rdfs:label": do.label,
                "datacite:hasDescription": do.description,
            }
            for do in query
        ]

    return result
