# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from rest_framework import serializers

from heliport.core.models import DigitalObject, DigitalObjectRelation


class DigitalObjectSerializer(serializers.ModelSerializer):
    class Meta:
        model = DigitalObject
        fields = [
            "digital_object_id",
            "projects",
            "persistent_id",
            "category",
            "label",
            "description",
            "co_owners",
            "owner",
        ]


class DigitalObjectRelationSerializer(serializers.ModelSerializer):
    subject__label = serializers.CharField(source="subject.label")
    subject__persistent_id = serializers.CharField(source="subject.persistent_id")
    predicate__label = serializers.CharField(source="predicate.label")
    predicate__persistent_id = serializers.CharField(source="predicate.persistent_id")
    object__label = serializers.CharField(source="object.label")
    object__persistent_id = serializers.CharField(source="object.persistent_id")

    class Meta:
        model = DigitalObjectRelation
        fields = [
            "digital_object_relation_id",
            "subject",
            "subject__label",
            "subject__persistent_id",
            "predicate",
            "predicate__label",
            "predicate__persistent_id",
            "object",
            "object__label",
            "object__persistent_id",
        ]
