# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import include, path
from rest_framework import routers

from .views import (
    DigitalObjectDeleteView,
    DigitalObjectPropertiesView,
    DigitalObjectRelationViewSet,
    DigitalObjectViewSet,
    ObjectGraphListView,
    ObjectGraphView,
    ObjectsView,
    SaveCategoryView,
    SearchView,
)

app_name = "digital_objects"
urlpatterns = [
    path("project/<int:project>/list/", ObjectsView.as_view(), name="list"),
    path(
        "project/<int:project>/delete/",
        DigitalObjectDeleteView.as_view(),
        name="delete",
    ),
    path("properties/", DigitalObjectPropertiesView.as_view(), name="properties"),
    path("category/save/", SaveCategoryView.as_view(), name="save_category"),
    path(
        "project/<int:project>/object_graph/<int:pk>/",
        ObjectGraphView.as_view(),
        name="object_graph",
    ),
    path(
        "project/<int:project>/object_graph/list/",
        ObjectGraphListView.as_view(),
        name="object_graph_list",
    ),
    path(
        "project/<int:project>/object_graph/<int:pk>/update/",
        ObjectGraphListView.as_view(),
        name="object_graph_update",
    ),
    path("search", SearchView.as_view(), name="search"),
]

# for REST API:
router = routers.DefaultRouter()
router.register(r"digital_objects", DigitalObjectViewSet, basename="digital_objects")
router.register(
    r"digital_object_relations",
    DigitalObjectRelationViewSet,
    basename="digital_object_relations",
)

urlpatterns += [
    path("api-root/", router.get_api_root_view(), name="api_root"),
    path("api/", include(router.urls)),
]
