# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class DocumentationModule(Module):
    name = "Documentation"
    module_id = "documentation"

    def get_url(self, project):
        return reverse("documentation:list", kwargs={"project": project.pk})

    def is_configured(self, project):
        from .models import Documentation

        return Documentation.objects.filter(projects=project)


def get_api_root():
    return reverse("documentation:api_root")


def get_search_url():
    return reverse("documentation:search")


def serialize_project(project):
    from .models import Documentation

    query = Documentation.objects.filter(projects=project)
    result = {}
    if query:
        result["heliport:has_Documentation"] = [
            {
                "heliport:documentation_id": doc.documentation_id,
                "datacite:uri": doc.link,
                "heliport:documentation_system": dict(doc.DOCU_SYSTEMS).get(doc.system),
                "datacite:hasDescription": doc.description,
            }
            for doc in query
        ]

    return result
