# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from rest_framework import serializers

from heliport.core.attribute_description import (
    EnumAttribute,
    EnumStringT,
    TypeAttribute,
)
from heliport.core.models import Vocabulary
from heliport.core.serializers import (
    DigitalObjectDATACITESerializer,
    datacite_serializers,
    register_digital_object_attributes,
)
from heliport.core.vocabulary import FABIO

from .models import Documentation


class DocumentationSerializer(serializers.ModelSerializer):
    link = serializers.CharField()

    def create(self, validated_data):
        link = validated_data.pop("link")
        instance = super().create(validated_data)
        instance.link = link
        return instance

    class Meta:
        model = Documentation
        fields = ["documentation_id", "description", "system", "link", "projects"]


@datacite_serializers.register(Documentation)
class DocumentationDATACITESerializer(DigitalObjectDATACITESerializer):
    def resource_type(self, doc):
        if doc.system == doc.DOCU_OPEN_BIS:
            return "OpenBis", "Collection"
        if doc.system == doc.DOCU_MEDIA_WIKI:
            return "MediaWiki", "Text"
        if doc.system == doc.DOCU_LIMS:
            return "Lims", "Other"
        if doc.system == doc.DOCU_HEDGEDOC:
            return "HedgeDoc", "Text"
        return "documentation", "Other"


@register_digital_object_attributes(Documentation)
def docu_attributes():
    return [
        TypeAttribute(FABIO.PersonalCommunication),
        EnumAttribute(
            Vocabulary().type,
            EnumStringT({Documentation.DOCU_OTHER: "documentation"}),
            "system",
            is_public=True,
        ),
    ]
