# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import include, path
from rest_framework import routers

from .views import (
    DocumentationUpdateView,
    DocumentationView,
    DocumentationViewSet,
    SearchView,
)

app_name = "documentation"
urlpatterns = [
    path("project/<int:project>/list/", DocumentationView.as_view(), name="list"),
    path(
        "project/<int:project>/update/<int:pk>/",
        DocumentationUpdateView.as_view(),
        name="update",
    ),
    path("search/", SearchView.as_view(), name="search"),
]

# for REST API:
router = routers.DefaultRouter()
router.register(r"documentation", DocumentationViewSet, basename="documentation")

urlpatterns += [
    path("api-root/", router.get_api_root_view(), name="api_root"),
    path("api/", include(router.urls)),
]
