# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class GATEConnectionModule(Module):
    name = "GATE Connection"
    module_id = "gate_connection"
    icon = "fa-solid fa-clipboard"

    def get_url(self, project):
        from .models import GateProject

        gate_project = GateProject.objects.filter(projects=project).first()
        if gate_project is None:
            return reverse("gate_connection:connect", kwargs={"project": project.pk})

        return reverse(
            "gate_connection:connected",
            kwargs={"project": project.pk, "pk": gate_project.pk},
        )

    def is_configured(self, project):
        from .models import GateProject

        return GateProject.objects.filter(projects=project)


def get_api_root():
    return reverse("gate_connection:api_root")


def get_search_url():
    return reverse("gate_connection:search")


def get_project_create_urls():
    return {"Create Project from GATE": reverse("gate_connection:create_project")}


def serialize_project(project):
    from .models import GateProject

    query = GateProject.objects.filter(projects=project)
    if not query:
        return {}

    def user_dict(user):
        return {
            "datacite:hasIdentifier": user.authentication_backend_id,
            "datacite:orcid": user.orcid,
            "rdfs:label": user.display_name,
        }

    gate_projects = []
    for gate_project in query:
        result = {
            "heliport:gate_id": gate_project.gate_id,
            "dc:title": gate_project.title,
            "heliport:status": gate_project.status,
            "dc:abstract": gate_project.abstract,
            "datacite:hasIdentifier": gate_project.proposal,
            "dc:accessRights": not gate_project.restricted,
        }

        if gate_project.proposer:
            result["dc:creator"] = user_dict(gate_project.proposer)
        if gate_project.responsible_experimentalist:
            result["heliport:responsible_experimentalist"] = user_dict(
                gate_project.responsible_experimentalist
            )

        co_proposer = [user_dict(guy) for guy in gate_project.co_proposer.all()]
        if co_proposer:
            result["dc:contributor"] = co_proposer

        local_contacts = [user_dict(guy) for guy in gate_project.local_contacts.all()]
        if local_contacts:
            result["heliport:local_contacts"] = local_contacts

        gate_projects.append(result)

    return {"heliport:has_GATEProject": gate_projects}
