# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from heliport.core.user_logic.user_information import LdapUserInformationManager

from .user_management import User, UserQueries


class LDAPUser(User):
    @classmethod
    def extract_users(cls, project):
        return project.local_contacts

    def __init__(self, ldap_id):
        self.ldap_id = str(ldap_id)
        self.name = None

    def __hash__(self):
        return hash(self.ldap_id)

    def __eq__(self, other):
        if isinstance(other, LDAPUser):
            return self.ldap_id == other.ldap_id
        else:
            return False

    def download(self, user_info_manager: LdapUserInformationManager):
        db_user = user_info_manager.get_user_by_id(self.ldap_id)
        assert db_user is not None, f"invalid ldap info for user {self.ldap_id}"
        self.name = db_user.display_name

    def get_db_user_from(self, user_queries: UserQueries):
        user = user_queries.get_user_by_ldap_id(self.ldap_id)
        if user is None:
            user = user_queries.create_user()
        return user

    def save_to(self, user_queries: UserQueries):
        user = self.get_db_user_from(user_queries)
        user_queries.update_user(user, display_name=self.name, ldap_id=self.ldap_id)

    def check_new(self, user_queries: UserQueries):
        return user_queries.get_user_by_ldap_id(self.ldap_id) is None
