# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import include, path
from rest_framework import routers

from .views import (
    ConnectedToGateProjectView,
    ConnectToGateProjectView,
    GateProjectViewSet,
    GateUserViewSet,
    ProjectCreateView,
    SearchView,
)

app_name = "gate_connection"
urlpatterns = [
    path(
        "project/<int:project>/list/",
        ConnectToGateProjectView.as_view(),
        name="connect",
    ),
    path(
        "project/<int:project>/gate/<int:pk>/",
        ConnectedToGateProjectView.as_view(),
        name="connected",
    ),
    path("search/", SearchView.as_view(), name="search"),
    path("create/project/", ProjectCreateView.as_view(), name="create_project"),
]

# for REST API:
router = routers.DefaultRouter()
router.register(r"gate_project", GateProjectViewSet, basename="gate_project")
router.register(r"gate_user", GateUserViewSet, basename="gate_user")

urlpatterns += [
    path("api-root/", router.get_api_root_view(), name="api_root"),
    path("api/", include(router.urls)),
]
