# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class PublicationModule(Module):
    name = "Publication"
    module_id = "publication"

    def get_url(self, project):
        return reverse("publication:list", kwargs={"project": project.pk})

    def is_configured(self, project):
        from .models import Publication

        return Publication.objects.filter(projects=project)


def get_api_root():
    return reverse("publication:api_root")


def get_search_url():
    return reverse("publication:search")


def serialize_project(project):
    from .models import Publication

    query = Publication.objects.filter(projects=project)
    result = {}
    if query:
        result["heliport:has_Publication"] = [
            {
                "heliport:publication_id": pub.publication_id,
                "datacite:hasDescription": pub.description,
            }
            for pub in query
        ]

    return result
