# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from rdflib import Namespace
from rest_framework import serializers

from heliport.core.attribute_description import TypeAttribute
from heliport.core.serializers import (
    DigitalObjectDATACITESerializer,
    datacite_serializers,
    register_digital_object_attributes,
)

from .models import Publication

DCMITYPE = Namespace("http://purl.org/dc/dcmitype/")


class PublicationSerializer(serializers.ModelSerializer):
    url = serializers.CharField(source="link")

    def create(self, validated_data):
        link = validated_data.pop("link")
        instance = super().create(validated_data)
        instance.link = link
        return instance

    class Meta:
        model = Publication
        fields = ["publication_id", "description", "projects", "persistent_id", "url"]


@datacite_serializers.register(Publication)
class PublicationDATACITESerializer(DigitalObjectDATACITESerializer):
    def resource_type(self, pub):
        return "publication", "Dataset"


@register_digital_object_attributes(Publication)
def publication_attributes():
    return [
        TypeAttribute(DCMITYPE.Dataset),
    ]
