# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import include, path
from rest_framework import routers

from .views import PublicationView, PublicationViewSet, SearchView

app_name = "publication"
urlpatterns = [
    path("project/<int:project>/list/", PublicationView.as_view(), name="list"),
    path(
        "project/<int:project>/update/<int:pk>/",
        PublicationView.as_view(),
        name="update",
    ),
    path("search/", SearchView.as_view(), name="search"),
]

# for REST API:
router = routers.DefaultRouter()
router.register(r"publications", PublicationViewSet, basename="publications")

urlpatterns += [
    path("api-root/", router.get_api_root_view(), name="api_root"),
    path("api/", include(router.urls)),
]
