# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class ShareLaTeXModule(Module):
    name = "Share LaTeX"
    module_id = "sharelatex"

    def get_url(self, project):
        return reverse("sharelatex:list", kwargs={"project": project.pk})

    def is_configured(self, project):
        from .models import ShareLaTeX

        return ShareLaTeX.objects.filter(projects=project)


def get_api_root():
    return reverse("sharelatex:api_root")


def get_search_url():
    return reverse("sharelatex:search")


def serialize_project(project):
    from .models import ShareLaTeX

    query = ShareLaTeX.objects.filter(projects=project)
    result = {}
    if query:
        result["heliport:has_ShareLaTeX"] = [
            {
                "heliport:latex_id": lx.latex_id,
                "datacite:uri": lx.link,
                "rdfs:label": lx.label,
            }
            for lx in query
        ]

    return result
