# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from rest_framework import serializers

from heliport.core.attribute_description import TypeAttribute
from heliport.core.serializers import (
    DigitalObjectDATACITESerializer,
    datacite_serializers,
    register_digital_object_attributes,
)
from heliport.core.vocabulary import FABIO

from .models import ShareLaTeX


class LatexSerializer(serializers.ModelSerializer):
    url = serializers.CharField(source="link")

    def create(self, validated_data):
        link = validated_data.pop("link")
        instance = super().create(validated_data)
        instance.link = link
        return instance

    class Meta:
        model = ShareLaTeX
        fields = ["latex_id", "label", "projects", "url"]


@datacite_serializers.register(ShareLaTeX)
class TexDATACITESerializer(DigitalObjectDATACITESerializer):
    def resource_type(self, tex):
        return "latex", "Text"


@register_digital_object_attributes(ShareLaTeX)
def tex_attributes():
    return [
        TypeAttribute(FABIO.Manuscript),
    ]
