# SPDX-FileCopyrightText: 2023 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class SMBShareModule(Module):
    """The module to show SMB shares in HELIPORT project graph"""

    name = "SMB Shares"
    module_id = "smb_shares"

    def get_url(self, project):
        """list url for SMB shares"""
        return reverse("smb_files:list", kwargs={"project": project.pk})

    def is_configured(self, project):
        """
        shown in project graph when :class:`heliport.smb_files.models.DBSMBDirectory`
        exists in project
        """
        from .models import DBSMBDirectory

        return DBSMBDirectory.objects.filter(
            projects=project, deleted__isnull=True
        ).exists()


def get_api_root():
    """register api root for smb files and directories"""
    return reverse("smb_files:api_root")


def get_search_url():
    """register url for searching smb files and directories"""
    return reverse("smb_files:search")
