# SPDX-FileCopyrightText: 2023 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import include, path
from rest_framework import routers

from .views import DirectoryViewSet, FileViewSet, SearchView, SMBView

app_name = "smb_files"
urlpatterns = [
    path("project/<int:project>/list/", SMBView.as_view(), name="list"),
    path(
        "project/<int:project>/update/<int:pk>/",
        SMBView.as_view(),
        name="update",
    ),
    path("search/", SearchView.as_view(), name="search"),
]

# for REST API:
router = routers.DefaultRouter()
router.register(r"smb_files", FileViewSet, basename="smb_files")
router.register(r"smb_directories", DirectoryViewSet, basename="smb_directories")

urlpatterns += [
    path("api-root/", router.get_api_root_view(), name="api_root"),
    path("api/", include(router.urls)),
]
