# SPDX-FileCopyrightText: 2023 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class SSHModule(Module):
    """
    HELIPORT module in project graph that lists ssh files and directories and allows
    addition and editing.
    """

    #: name in HELIPORT project graph
    name = "SSH Files/Directories"
    #: name in settings
    module_id = "ssh_files_directories"

    def get_url(self, project):
        """url when user clicks on this in project graph"""
        return reverse("ssh:list", kwargs={"project": project.pk})

    def is_configured(self, project):
        """shown in project graph if files or directories added to project"""
        from .models import DBSSHDirectory, DBSSHFile

        files = DBSSHFile.objects.filter(projects=project, deleted__isnull=True)
        dirs = DBSSHDirectory.objects.filter(projects=project, deleted__isnull=True)
        return files.union(dirs).exists()


def get_api_root():
    """ssh api root url to register with HELIPORT api overview"""
    return reverse("ssh:api_root")


def get_search_url():
    """url to get search results; used to implement global HELIPORT string search"""
    return reverse("ssh:search")
