# SPDX-FileCopyrightText: 2023 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import include, path
from rest_framework import routers

from .views import (
    DirectoryViewSet,
    FileViewSet,
    MigrateDataSourceView,
    SearchView,
    SSHListView,
)

app_name = "ssh"

urlpatterns = [
    path("project/<int:project>/list/", SSHListView.as_view(), name="list"),
    path(
        "project/<int:project>/<str:type>/update/<int:pk>/",
        SSHListView.as_view(),
        name="update",
    ),
    path("search/", SearchView.as_view(), name="search"),
    path(
        "project/<int:project>/migrate/",
        MigrateDataSourceView.as_view(),
        name="migrate",
    ),
]

# for REST API:
router = routers.DefaultRouter()
router.register(r"files", FileViewSet, basename="files")
router.register(r"directories", DirectoryViewSet, basename="directories")

urlpatterns += [
    path("api-root/", router.get_api_root_view(), name="api_root"),
    path("api/", include(router.urls)),
]
