# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import path

from .views import (
    TableDataView,
    TableDeleteColumnView,
    TableDeleteRowView,
    TableEditView,
    TableResetCellView,
    TablesView,
    TableUpdateColumnView,
    TableUpdateRowView,
)

app_name = "tables"
urlpatterns = [
    path("project/<int:project>/list/", TablesView.as_view(), name="list"),
    path("project/<int:project>/edit/<int:pk>/", TableEditView.as_view(), name="edit"),
    path(
        "project/<int:project>/list/<int:pk>/edit/",
        TablesView.as_view(),
        name="edit_in_list",
    ),
    path(
        "project/<int:project>/edit/<int:pk>/column/",
        TableUpdateColumnView.as_view(),
        name="edit_column",
    ),
    path(
        "project/<int:project>/edit/<int:pk>/table_data/",
        TableDataView.as_view(),
        name="table_data",
    ),
    path(
        "project/<int:project>/edit/<int:pk>/row/",
        TableUpdateRowView.as_view(),
        name="edit_row",
    ),
    path(
        "project/<int:project>/edit/<int:pk>/delete_column/",
        TableDeleteColumnView.as_view(),
        name="delete_column",
    ),
    path(
        "project/<int:project>/edit/<int:pk>/delete_row/",
        TableDeleteRowView.as_view(),
        name="delete_row",
    ),
    path(
        "project/<int:project>/edit/<int:pk>/reset_cell/",
        TableResetCellView.as_view(),
        name="reset_cell",
    ),
]
