# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.urls import reverse

from heliport.core.app_interaction import Module


class VersionControlModule(Module):
    """Show version controls in HELIPORT project graph"""

    name = "Version Control"
    module_id = "version_control"

    def get_url(self, project):
        return reverse("version_control:list", kwargs={"project": project.pk})

    def is_configured(self, project):
        from .models import VersionControl

        return VersionControl.objects.filter(projects=project)


def get_api_root():
    return reverse("version_control:api_root")


def get_search_url():
    return reverse("version_control:search")


def serialize_project(project):
    from .models import VersionControl

    query = VersionControl.objects.filter(projects=project)
    result = {}
    if query:
        result["heliport:has_VersionControl"] = [
            {
                "heliport:version_control_id": vc.version_control_id,
                "datacite:uri": vc.link,
                "rdfs:label": vc.label,
            }
            for vc in query
        ]

    return result
