# SPDX-FileCopyrightText: 2022 Helmholtz-Zentrum Dresden-Rossendorf (HZDR)
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.conf import settings
from django.contrib import admin
from django.urls import include, path

urlpatterns = [
    # django.contrib apps
    path("admin/", admin.site.urls),
    # Third-party apps
    path("__debug__/", include("debug_toolbar.urls")),
    path("health/", include("health_check.urls")),
    path("qr_code/", include("qr_code.urls", namespace="qr_code")),
    # heliport apps
    path("", include("heliport.core.urls")),
    path("version_control/", include("heliport.version_control.urls")),
    path("data_management_plan/", include("heliport.data_management_plan.urls")),
    path("documentation/", include("heliport.documentation.urls")),
    path("data_source/", include("heliport.data_source.urls")),
    path("archive/", include("heliport.archive.urls")),
    path("publication/", include("heliport.publication.urls")),
    path("cwl_execution/", include("heliport.cwl_execution.urls")),
    path("digital_objects/", include("heliport.digital_objects.urls")),
    path("sharelatex/", include("heliport.sharelatex.urls")),
    path("tables/", include("heliport.tables.urls")),
    path("ssh/", include("heliport.ssh.urls")),
    path("smb/", include("heliport.smb_files.urls")),
]

if settings.HELIPORT_GATE_ENABLED:
    urlpatterns.append(
        path("gate_connection/", include("heliport.gate_connection.urls"))
    )

if settings.HELIPORT_UNICORE_ENABLED:
    urlpatterns.append(path("unicore/", include("heliport.unicore.urls")))
